APP = 'Translatable-Enums'
DESCRIPTION = ('Translatable-Enums is a i18n tool which uses built-in Enums '
               'as an convenient way to store translation keys.')
VERSION = '0.0.2'
AUTHOR = 'crazyproger1'
