from .shortcuts import (
    set_language,
    set_domain,
    get_language
)

from .contexts import (
    language
)

__all__ = [
    'set_domain',
    'set_language',
    'get_language',
    'language'
]
